@@ -42,7 +42,7 @@ def date_to_timestamp(d):
 def date_to_timestamp_ext(d):
     try:
         return date_to_timestamp(d)
-    except ValueError:
+    except (ValueError, TypeError):
         return int(d)
 
 
@@ -68,6 +68,19 @@ def week_to_date(week):
             strftime('%Y-%m-%d %H:%M:%S'))
 
 
+def timestamp_to_day(timestamp):
+    return timestamp // (24 * 3600)
+
+
+def timestamp_to_utc_date(timestamp):
+    return (datetime.datetime.fromtimestamp(timestamp).
+            strftime('%Y-%m-%d'))
+
+
+def round_timestamp_to_day(timestamp):
+    return (int(timestamp) // (24 * 3600)) * (24 * 3600)
+
+
 def check_email_validity(email):
     if email:
         return re.match(r'[\w\d_\.-]+@([\w\d_\.-]+\.)+[\w]+', email)
@@ -81,14 +94,16 @@ def read_uri(uri):
         fd.close()
         return raw
     except Exception as e:
-        LOG.warn('Error while reading uri: %s' % e)
+        LOG.warn('Error "%(error)s" while reading uri %(uri)s',
+                 {'error': e, 'uri': uri})
 
 
 def read_json_from_uri(uri):
     try:
         return json.loads(read_uri(uri))
     except Exception as e:
-        LOG.warn('Error parsing json: %s' % e)
+        LOG.warn('Error "%(error)s" parsing json from uri %(uri)s',
+                 {'error': e, 'uri': uri})
 
 
 def make_range(start, stop, step):
@@ -165,6 +180,10 @@ def get_blueprint_id(module, name):
     return module + ':' + name
 
 
+def get_bug_id(module, bug_id):
+    return module + '/' + bug_id
+
+
 def get_patch_id(review_id, patch_number):
     return review_id + ':' + patch_number
 
@@ -181,7 +200,7 @@ def add_index(sequence, start=1, item_filter=lambda x: True):
 
 
 def safe_encode(s):
-    return parse.quote_plus(s.encode('utf-8'))
+    return parse.quote(s.encode('utf-8'))
 
 
 def make_module_group(module_group_id, name=None, modules=None, tag='module'):
@@ -189,3 +208,22 @@ def make_module_group(module_group_id, name=None, modules=None, tag='module'):
             'module_group_name': name or module_group_id,
             'modules': modules or [module_group_id],
             'tag': tag}
+
+BAD_NAME_SUFFIXES = ['Ltd', 'Pvt', 'Inc', 'GmbH', 'AG', 'Corporation', 'Corp',
+                     'Company', 'Co', 'Group', 'Srl', 'Limited', 'LLC', 'IT']
+
+BAD_NAME_SUFFIXES_WITH_STOPS = ['S.p.A.', 's.r.o.', 'L.P.', 'B.V.', 'K.K.',
+                                'd.o.o.']
+
+
+def normalize_company_name(name):
+    regex = '(\\b(' + '|'.join(BAD_NAME_SUFFIXES) + ')\\b)'
+    regex += '|' + '((^|\\s)(' + '|'.join(BAD_NAME_SUFFIXES_WITH_STOPS) + '))'
+    name = re.sub(re.compile(regex, re.IGNORECASE), '', name)
+    return ''.join([c.lower() for c in name if c.isalnum()])
+
+
+def normalize_company_draft(name):
+    name = re.sub(',', ' ', name)
+    name = re.sub(r'\s+', ' ', name)
+    return name
